Modules
Macros
Structs
Traits
Functions
- from_
bytes - Deserializes a binary slice into a value of type
Tusing the default configuration. - from_
bytes_ with_ config - Deserializes a binary slice into a value of type
Tusing a custom configuration. - to_
bytes - Serializes a given value into a binary format using the default configuration.
- to_
bytes_ with_ config - Serializes a given value into a binary format using a custom configuration.